==> netbeans_6.1.orig.tar.gz: netbeans-6.1/versioning/src/org/netbeans/modules/versioning/VcsCollocationQueryImplementation.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.versioning;

import org.netbeans.spi.queries.CollocationQueryImplementation;
import org.netbeans.modules.versioning.spi.VersioningSystem;

import java.io.File;

/**
 * Delegates the work to the owner of files in query.
 * 
 * @author Maros Sandor
 */
public class VcsCollocationQueryImplementation implements CollocationQueryImplementation {

    public boolean areCollocated(File a, File b) {
        VersioningSystem vsa = VersioningManager.getInstance().getOwner(a);
        VersioningSystem vsb = VersioningManager.getInstance().getOwner(b);
        if (vsa == null || vsa != vsb) return false;
        
        if (vsa instanceof CollocationQueryImplementation) {
            CollocationQueryImplementation csa = (CollocationQueryImplementation) vsa;
            return csa.areCollocated(a, b);
        }
        return false;
    }

    public File findRoot(File file) {
        VersioningSystem system = VersioningManager.getInstance().getOwner(file);
        return system == null ? null : system.getTopmostManagedAncestor(file);
    }
}

==> netbeans_6.5.orig.tar.gz: netbeans-6.5/versioning/src/org/netbeans/modules/versioning/VcsCollocationQueryImplementation.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.versioning;

import org.netbeans.spi.queries.CollocationQueryImplementation;
import org.netbeans.modules.versioning.spi.VersioningSystem;

import java.io.File;

/**
 * Delegates the work to the owner of files in query.
 * 
 * @author Maros Sandor
 */
public class VcsCollocationQueryImplementation implements CollocationQueryImplementation {

    public boolean areCollocated(File a, File b) {
        VersioningSystem vsa = VersioningManager.getInstance().getOwner(a);
        VersioningSystem vsb = VersioningManager.getInstance().getOwner(b);
        if (vsa == null || vsa != vsb) return false;
        
        CollocationQueryImplementation cqi = vsa.getCollocationQueryImplementation();
        return cqi != null && cqi.areCollocated(a, b);
    }

    public File findRoot(File file) {
        VersioningSystem system = VersioningManager.getInstance().getOwner(file);
        CollocationQueryImplementation cqi = system.getCollocationQueryImplementation();
        return cqi == null ? null : cqi.findRoot(file);
    }
}
